@@ -78,26 +78,30 @@ def _get_actuals(
     col: Optional[str] = "cpr",
     wide: bool = True,
 ) -> Optional[pd.DataFrame]:
-    out = pd.concat(
-        [
-            _get_pool_actuals(
-                client=client,
-                cusips=symbols,
-                start=start,
-                end=end,
-                col=col,
-                wide=wide,
-            ),
-            _get_cohort_actuals(
-                client=client,
-                cohorts=symbols,
-                start=start,
-                end=end,
-                col=col,
-                wide=wide,
-            ),
-        ]
+    dfs = []
+    pool_df = _get_pool_actuals(
+        client=client,
+        cusips=symbols,
+        start=start,
+        end=end,
+        col=col,
+        wide=wide,
     )
+    if pool_df is not None and len(pool_df) > 0:
+        dfs.append(pool_df)
+
+    cohort_df = _get_cohort_actuals(
+        client=client,
+        cohorts=symbols,
+        start=start,
+        end=end,
+        col=col,
+        wide=wide,
+    )
+    if cohort_df is not None and len(cohort_df) > 0:
+        dfs.append(cohort_df)
+
+    out = pd.concat(dfs)
     return out
 
 
